Workdir Api
=============


.. currentmodule:: anyvc.workdir

.. autofunction:: open

.. autofunction:: checkout

.. autofunction:: clone

.. currentmodule:: anyvc.common.workdir

.. autoclass:: WorkDir
  :members:

.. autoclass:: WorkDirWithParser
  :members:

.. currentmodule anyvc.common.statedpath

.. autoclass:: StatedPath
  :members:
